@@ -643,6 +643,57 @@ test_generated_nas_get_cell_location_info (TestFixture *fixture)
     test_fixture_loop_run (fixture);
 }
 
+/*****************************************************************************/
+
+static void
+nas_get_cell_location_info_invalid_response_ready (QmiClientNas *client,
+                                                   GAsyncResult *res,
+                                                   TestFixture  *fixture)
+{
+    QmiMessageNasGetCellLocationInfoOutput *output;
+    GError *error = NULL;
+
+    output = qmi_client_nas_get_cell_location_info_finish (client, res, &error);
+    g_assert_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_UNEXPECTED_MESSAGE);
+    g_assert (!output);
+
+    test_fixture_loop_stop (fixture);
+}
+
+static void
+test_generated_nas_get_cell_location_info_invalid_response (TestFixture *fixture)
+{
+    guint8 expected[] = {
+        0x01,
+        0x0C, 0x00, 0x00, 0x03, 0x01,
+        0x00, 0x01, 0x00, 0x43, 0x00, 0x00, 0x00
+    };
+    guint8 response[] = {
+        0x01,
+        0x53, 0x00, 0x80, 0x03, 0x01,
+        0x02, 0x01, 0x00, 0x44, 0x00, 0x47, 0x00, 0x02, /* command id set to 0x0044 instead of 0x0043 */
+        0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x3D,
+        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+        0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF,
+        0xFF, 0x28, 0x00, 0x03, 0x7D, 0x6F, 0x00, 0x00,
+        0x32, 0xF4, 0x51, 0xB3, 0x00, 0x4D, 0x00, 0x11,
+        0x2A, 0x00, 0x8A, 0x3C, 0x00, 0x00, 0x32, 0xF4,
+        0x51, 0xB3, 0x00, 0x63, 0x00, 0x30, 0x14, 0x00,
+        0x89, 0x3C, 0x00, 0x00, 0x32, 0xF4, 0x51, 0xB3,
+        0x00, 0x59, 0x00, 0x11, 0x0D, 0x00
+    };
+
+    test_port_context_set_command (fixture->ctx,
+                                   expected, G_N_ELEMENTS (expected),
+                                   response, G_N_ELEMENTS (response),
+                                   fixture->service_info[QMI_SERVICE_NAS].transaction_id++);
+
+    qmi_client_nas_get_cell_location_info (QMI_CLIENT_NAS (fixture->service_info[QMI_SERVICE_NAS].client), NULL, 3, NULL,
+                                           (GAsyncReadyCallback) nas_get_cell_location_info_invalid_response_ready,
+                                           fixture);
+
+    test_fixture_loop_run (fixture);
+}
 
 /*****************************************************************************/
 
@@ -662,5 +713,8 @@ int main (int argc, char **argv)
     TEST_ADD ("/libqmi-glib/generated/nas/network-scan",           test_generated_nas_network_scan);
     TEST_ADD ("/libqmi-glib/generated/nas/get-cell-location-info", test_generated_nas_get_cell_location_info);
 
+    /* Invalid responses */
+    TEST_ADD ("/libqmi-glib/generated/nas/invalid/get-cell-location-info", test_generated_nas_get_cell_location_info_invalid_response);
+
     return g_test_run ();
 }
